@@ -67,6 +67,42 @@ class SalesForceAPI:
         response = self.call_api(request_url)
         return response
 
+    def PermissionSetLicense(self, fields=None):
+        if not fields:
+            fields = [
+                'Id', 'PermissionSetLicenseKey', 'DeveloperName', 'TotalLicenses',
+                'UsedLicenses', 'Status'
+            ]
+        fields = ',+'.join(fields)
+        query = f'SELECT+{fields}+from+PermissionSetLicense'
+        request_url = f'{self.url}/services/data/v53.0/query?q={query}'
+        response = self.call_api(request_url)
+        return response
+
+    def TenantUsageEntitlement(self, fields=None):
+        if not fields:
+            fields = [
+                'MasterLabel', 'AmountUsed', 'CurrentAmountAllowed', 'Frequency', 
+                'IsPersistentResource', 'UsageDate' 
+            ]
+        fields = ',+'.join(fields)
+        query = f'SELECT+{fields}+from+TenantUsageEntitlement'
+        request_url = f'{self.url}/services/data/v53.0/query?q={query}'
+        response = self.call_api(request_url)
+        return response
+
+    def ActiveFeatureLicenseMetric(self, fields=None):
+        if not fields:
+        fields = [
+            'ActiveUserCount', 'AssignedUserCount', 'FeatureType',
+            'MetricsDate', 'TotalLicenseCount'
+        ]
+        fields = ',+'.join(fields)
+        query = f'SELECT+{fields}+from+ActiveFeatureLicenseMetric'
+        request_url = f'{self.url}/services/data/v53.0/query?q={query}'
+        response = self.call_api(request_url)
+        return response
+    
     def userLicense(self, fields=None):
         if not fields:
             fields = [
@@ -82,4 +118,5 @@ class SalesForceAPI:
 
     def call_api(self, url):
         response = requests.get(url, headers=self.headers)
+        response = json.loads(response.text)
         return response
